@@ -1,5 +1,5 @@
 from base64 import b64encode
-from requests import Session
+import requests
 from .errors import EmptyImage, InvalidToken, ServerError, TooManyRequests
 
 class TraceMoe:
@@ -8,8 +8,6 @@ class TraceMoe:
         self.base_url = "https://trace.moe/"
         self.media_url = "https://media.trace.moe/"
         self.api_token = api_token
-        self.r_session = Session()
-        self.r_session.headers = {"Content-Type": "application/json"}
     
     def get_me(self) -> dict:
         """
@@ -19,7 +17,7 @@ class TraceMoe:
         """
         url = f"{self.base_url}me"
         if self.api_token: url += f"?token={self.token}"
-        return self.r_session.get(url).json()
+        return requests.get(url).json()
     
     def search(self, path:str, encode:bool=True, is_url:bool=False) -> dict:
         """
@@ -39,18 +37,18 @@ class TraceMoe:
             url += f"?token={self.api_token}"
 
         if is_url:
-            response = self.r_session.get(
+            response = requests.get(
                 url, params={"url": path}
             ).json()
 
         elif encode:
             with open(path, "rb") as f:
                 encoded = b64encode(f.read()).decode("utf-8")
-                response = self.r_session.post(
+                response = requests.post(
                 url, json={"image": encoded}
                 )
         else:
-            response = self.r_session.post(
+            response = requests.post(
                 url, json={"image": encoded}
                 )
         if response.status_code == 200:
@@ -76,8 +74,7 @@ class TraceMoe:
         json = json["docs"][index]
         url = f"{self.base_url}{path}?anilist_id={json['anilist_id']}"\
               f"&file={json['filename']}&t={json['at']}&token={json['tokenthumb']}"
-        print(url)
-        return self.r_session.get(url).content
+        return requests.get(url).content
     
     def image_preview(self, json:dict, index:int = 0) -> bytes:
         """
@@ -98,5 +95,21 @@ class TraceMoe:
            bytes: Video content
         """
         return self.create_preview(json, 'preview.php', index)
+    
+    def natural_preview(self, response:dict, index:int=0, mute:bool=False) -> bytes:
+        """
+        Video Preview with Natural Scene Cutting
+        Arguments:
+            response: server response
+            index: which result to pick
+            mute: mute video or not.
+        Returns:
+            bytes: Video content
+        """
+        response = response["docs"][index]
+        url = f'{self.media_url}video/{response["anilist_id"]}/'\
+              f'{response["filename"]}?t={response["at"]}&{token=response["tokenthumb"]}'
+        if mute: url += "&mute"
+        return requests.get(url).content
         
         
